@@ -1,5 +1,6 @@
 import logging
 
+from django.contrib.auth import get_user
 from django.http import Http404
 from power_dict.errors import NoneParameterError, InvalidParameterError, InvalidSchemeError, NotAllowedParameterError
 from power_dict.utils import DictUtils
@@ -61,7 +62,7 @@ class DrfUtils:
             if type(request.data) == dict:
                 qp = request.data
             else:
-                qp = request.data.dict()
+                qp = dict(request.data)
             result = {**result, **qp}
 
         return result
@@ -118,7 +119,7 @@ class DrfUtils:
 
     @staticmethod
     def get_current_user(request):
-        user = request.user
+        user = get_user(request)
         from django.contrib.auth.models import AnonymousUser
         if type(user) is AnonymousUser:
             return None
